@@ -21,6 +21,8 @@ from .inventory.render import extract_components
 from .inventory.parameters import InventoryFacts
 from .inventory.lint import LINTERS
 from .login import login, fetch_token
+from .package.compile import compile_package
+from .package.template import PackageTemplater
 
 pass_config = click.make_pass_decorator(Config)
 
@@ -215,13 +217,6 @@ def compile_catalog(
             "Cannot push changes when local global or tenant repo override is specified"
         )
 
-    if not local:
-        if not fetch_dependencies:
-            click.echo(
-                "--no-fetch-dependencies doesn't take effect unless --local is specified"
-            )
-        # Ensure we always fetch dependencies in regular mode
-        fetch_dependencies = True
     config.fetch_dependencies = fetch_dependencies
 
     if config.api_token is None and not local:
@@ -330,8 +325,7 @@ def component_new(
     verbose,
 ):
     config.update_verbosity(verbose)
-    f = ComponentTemplater(config, slug)
-    f.name = name
+    f = ComponentTemplater(config, slug, name=name)
     f.library = lib
     f.post_process = pp
     f.github_owner = owner
@@ -405,6 +399,162 @@ def component_compile(
     compile_component(config, path, alias, values, search_paths, output)
 
 
+@commodore.group(short_help="Interact with a Commodore config package")
+@verbosity
+@pass_config
+def package(config: Config, verbose: int):
+    config.update_verbosity(verbose)
+
+
+@package.command(name="new", short_help="Create a new config package from a template")
+@click.argument("slug")
+@click.option(
+    "--name",
+    help="The package's name as it will be written in the documentation. Defaults to the slug.",
+)
+@click.option(
+    "--owner",
+    default="projectsyn",
+    show_default=True,
+    help="The GitHub user or project name where the package will be hosted.",
+)
+@click.option(
+    "--copyright",
+    "copyright_holder",
+    default="VSHN AG <info@vshn.ch>",
+    show_default=True,
+    help="The copyright holder added to the license file.",
+)
+@click.option(
+    "--golden-tests/--no-golden-tests",
+    default=True,
+    show_default=True,
+    help="Add golden tests to the package.",
+)
+@click.option(
+    "--template-url",
+    default="https://github.com/projectsyn/commodore-config-package-template.git",
+    show_default=True,
+    help="The URL of the package cookiecutter template.",
+)
+@click.option(
+    "--template-version",
+    default="main",
+    show_default=True,
+    help="The package template version (Git tree-ish) to use.",
+)
+@click.option(
+    "--output-dir",
+    default="",
+    show_default=True,
+    type=click.Path(file_okay=False, dir_okay=True),
+    help="The directory in which to place the new package.",
+)
+@click.option(
+    "--additional-test-case",
+    "-t",
+    metavar="CASE",
+    default=[],
+    show_default=True,
+    multiple=True,
+    help="Additional test cases to generate in the new package. Can be repeated. "
+    + "Test case `defaults` will always be generated.",
+)
+@verbosity
+@pass_config
+# pylint: disable=too-many-arguments
+def package_new(
+    config: Config,
+    verbose: int,
+    slug: str,
+    name: Optional[str],
+    owner: str,
+    copyright_holder: str,
+    golden_tests: bool,
+    template_url: str,
+    template_version: str,
+    output_dir: str,
+    additional_test_case: Iterable[str],
+):
+    """Create new config package repo from template.
+
+    The command line options allow the caller to customize the remote repository
+    location (only supports GitHub at the moment), the package's display name, whether
+    to configure golden tests, and the licensing details.
+    """
+    config.update_verbosity(verbose)
+    t = PackageTemplater(config, slug, name=name, output_dir=output_dir)
+    t.github_owner = owner
+    t.copyright_holder = copyright_holder
+    t.golden_tests = golden_tests
+    t.template_url = template_url
+    t.template_version = template_version
+    t.test_cases = ["defaults"] + list(additional_test_case)
+    t.create()
+
+
+@package.command(name="compile", short_help="Compile a config package standalone")
+@click.argument("path", type=click.Path(exists=True, file_okay=False, dir_okay=True))
+@click.argument(
+    "test_class", type=click.Path(exists=False, file_okay=True, dir_okay=False)
+)
+@click.option(
+    "-f",
+    "--values",
+    multiple=True,
+    type=click.Path(exists=True, file_okay=True, dir_okay=False),
+    help="Specify additional inventory class in a YAML file (can specify multiple).",
+)
+@click.option(
+    "--local",
+    is_flag=True,
+    default=False,
+    help=(
+        "Run in local mode, local mode reuses the contents of the working directory. "
+        + "Local mode won't fetch missing components."
+    ),
+)
+@click.option(
+    " / -F",
+    "--fetch-dependencies/--no-fetch-dependencies",
+    default=True,
+    help="Whether to fetch Jsonnet and Kapitan dependencies in local mode. "
+    + "By default dependencies are fetched.",
+)
+@click.option(
+    "-k / ",
+    "--keep-dir/--no-keep-dir",
+    default=False,
+    show_default=True,
+    help="Whether to keep the compilation temp directory after the compilation is done.",
+)
+@click.option(
+    "--tmp-dir",
+    default="",
+    metavar="PATH",
+    type=click.Path(exists=False, file_okay=False, dir_okay=True),
+    help="Temp directory to use for compilation. Implies `--keep-dir`",
+)
+@verbosity
+@pass_config
+# pylint: disable=too-many-arguments
+def package_compile(
+    config: Config,
+    verbose: int,
+    path: str,
+    test_class: str,
+    values: Iterable[str],
+    local: bool,
+    fetch_dependencies: bool,
+    keep_dir: bool,
+    tmp_dir: str,
+):
+    config.update_verbosity(verbose)
+    config.local = local
+    config.fetch_dependencies = fetch_dependencies
+    compile_package(config, path, test_class, values, tmp_dir, keep_dir)
+
+
 @commodore.group(short_help="Interact with a Commodore inventory")
 @verbosity
 @pass_config
